@@ -28,12 +28,18 @@ function(f,para,...) {
     else if(type == 'gum') {
       return(quagum(f,para))
     }
+    else if(type == 'kur') {
+      return(quakur(f,para))
+    }
     else if(type == 'ln3') {
       return(qualn3(f,para))
     }
     else if(type == 'ray') {
       return(quaray(f,para))
     }
+    else if(type == 'rice') {
+      return(quarice(f,para))
+    }
     else if(type == 'revgum') {
       return(quarevgum(f,para))
     }
