@@ -40,7 +40,7 @@ function(vec,type,nowarn=FALSE,...) {
     else if(type == 'kur') {
       z <- list(type = 'kur', para = vec, source = "vec2par")
       names(z$para) <- c("alpha","beta")
-    } 
+    }
     else if(type == 'ln3') {
       z <- list(type = 'ln3', para = vec, source = "vec2par")
       names(z$para) <- c("zeta","mu","sigma")
@@ -49,6 +49,10 @@ function(vec,type,nowarn=FALSE,...) {
       z <- list(type = 'ray', para = vec, source = "vec2par")
       names(z$para) <- c("xi","alpha")
     }
+    else if(type == 'rice') {
+      z <- list(type = 'rice', para = vec, source = "vec2par")
+      names(z$para) <- c("nu", "SNR")
+    }
     else if(type == 'revgum') {
       z <- list(type = 'revgum', para = c(vec[1],vec[2]),
                 zeta=vec[3], source = "vec2par")
